soap package
============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   soap.line_aware_stat
   soap.tools

Submodules
----------

soap.back\_soap module
----------------------

.. automodule:: soap.back_soap
   :members:
   :undoc-members:
   :show-inheritance:

soap.cli module
---------------

.. automodule:: soap.cli
   :members:
   :undoc-members:
   :show-inheritance:

soap.soap module
----------------

.. automodule:: soap.soap
   :members:
   :undoc-members:
   :show-inheritance:

soap.soap module
----------------

.. automodule:: soap.soap
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: soap
   :members:
   :undoc-members:
   :show-inheritance:
